@@ -68,8 +68,9 @@ static void		 destroy_board(void);
 #define VERTICAL_SEPARATION 20
 
 static char* background_images[] = {"gcompris/animals/tiger1_by_Ralf_Schmode","gcompris/animals/tigerdrink001.jpg","gcompris/animals/tigercub003.jpg", "gcompris/animals/tigerplay001.jpg"};
-static const char oper_values[] = {'+', '-', 'x', ':', '='};
-static const int num_values[] = {1,2,3,4,5,6,7,8,9,10,25,50,100};
+static const char  oper_values[] = {'+', '-', 'x', ':', '='};
+static const char *oper_images[] = {"plus", "minus", "by", "div", "equal"};
+static const int   num_values[] = {1,2,3,4,5,6,7,8,9,10,25,50,100};
 #define NUM_VALUES 13
 #define Y_OPE 20
 #define Y_NUM 100
@@ -195,7 +196,7 @@ static void start_board (GcomprisBoard *agcomprisBoard) {
       g_free(str);
     }
     for (i=0; i<5; i++) {
-      str = g_strdup_printf("%s/%c.png", gcomprisBoard->boarddir,oper_values[i]);
+      str = g_strdup_printf("%s/%s.png", gcomprisBoard->boarddir,oper_images[i]);
       oper_pixmap[i] = gcompris_load_pixmap(str);
       g_free(str);
     }
