@@ -1,6 +1,6 @@
 /* gcompris - planegame.c
  *
- * Time-stamp: <2001/12/03 01:13:54 bruno>
+ * Time-stamp: <2002/03/13 23:09:41 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -35,6 +35,8 @@ static GnomeCanvasItem *planeitem = NULL;
 static gint plane_x, plane_y;
 static gint planespeed_x, planespeed_y;
 
+#define MAXSPEED 7
+
 /* These are the index for managing the game rule */
 static gint plane_target, plane_last_target;
 
@@ -148,7 +150,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 
       /* set initial values for this level */
       gcomprisBoard->level = 1;
-      gcomprisBoard->maxlevel = 6;
+      gcomprisBoard->maxlevel = 2;
       gcompris_bar_set(GCOMPRIS_BAR_LEVEL);
 
       planegame_next_level();
@@ -170,6 +172,7 @@ end_board ()
       planegame_destroy_all_items();
       gcomprisBoard->level = 1;       // Restart this game to zero
     }
+  gcomprisBoard = NULL;
 }
 
 static void
@@ -186,8 +189,8 @@ set_level (guint level)
 gint key_press(guint keyval)
 {
 
-   if(!get_board_playing())
-     return FALSE;
+  if(!gcomprisBoard)
+    return TRUE;
 
   /* Add some filter for control and shift key */
   switch (keyval)
@@ -253,19 +256,19 @@ gint key_press(guint keyval)
       keyval=GDK_9;
       break;
     case GDK_Right:
-      if(planespeed_x < 3)
+      if(planespeed_x < MAXSPEED)
 	planespeed_x++;
       return TRUE;
     case GDK_Left:
-      if(planespeed_x > -3)
+      if(planespeed_x > -MAXSPEED)
 	planespeed_x--;
       return TRUE;
     case GDK_Up:
-      if(planespeed_y > -3)
+      if(planespeed_y > -MAXSPEED)
       planespeed_y--;
       return TRUE;
     case GDK_Down:
-      if(planespeed_y < 3)
+      if(planespeed_y < MAXSPEED)
       planespeed_y++;
       return TRUE;
     }
@@ -306,14 +309,14 @@ static void planegame_next_level()
 
   /* Try the next level */
   speed=100+(40/(gcomprisBoard->level));
-  fallSpeed=7000-gcomprisBoard->level*200;
+  fallSpeed=10000-gcomprisBoard->level*200;
   /* Make the images tend to 0.5 ratio */
-  imageZoom=0.5+(0.5/(gcomprisBoard->level));
+  imageZoom=0.3+(0.5/(gcomprisBoard->level));
 
   /* Setup and Display the plane */
   planespeed_y = 0;
   planespeed_x = 0;
-  str = g_strdup_printf("%s%s", pixmapsdir, "tuxplane.png");
+  str = g_strdup_printf("%s%s", pixmapsdir, "tuxhelico.png");
   pixmap = gcompris_load_pixmap(str);
   plane_x = 50;
   plane_y = 300;
@@ -322,8 +325,8 @@ static void planegame_next_level()
 				     "pixbuf", pixmap, 
 				     "x", (double) plane_x,
 				     "y", (double) plane_y,
-				     "width", (double) gdk_pixbuf_get_width(pixmap)*imageZoom*0.7,
-				     "height", (double) gdk_pixbuf_get_height(pixmap)*imageZoom*0.7,
+				     "width", (double) gdk_pixbuf_get_width(pixmap)*imageZoom,
+				     "height", (double) gdk_pixbuf_get_height(pixmap)*imageZoom,
 				     "width_set", TRUE, 
 				     "height_set", TRUE,
 				     NULL);
@@ -331,28 +334,38 @@ static void planegame_next_level()
 
   /* Game rules */
   plane_target = 1;
-  plane_last_target = gcomprisBoard->level*10;
+  plane_last_target = 10;
 
   gcomprisBoard->number_of_sublevel=plane_last_target;
-  gcompris_score_start(SCORESTYLE_NOTE, 
-		       gcomprisBoard->width - 220, 
-		       gcomprisBoard->height - 50, 
-		       gcomprisBoard->number_of_sublevel);
+
   gcomprisBoard->sublevel=plane_target;
-  gcompris_score_set(gcomprisBoard->sublevel);
+
+  if(gcomprisBoard->level>1)
+    {
+      /* No scoring after level 1 */
+      gcompris_score_end();
+    }
+  else
+    {
+      gcompris_score_start(SCORESTYLE_NOTE, 
+			   gcomprisBoard->width - 220, 
+			   gcomprisBoard->height - 50, 
+			   gcomprisBoard->number_of_sublevel);
+      gcompris_score_set(gcomprisBoard->sublevel);
+    }
+
 
   g_free (str);
 
 }
 
+#define ISIN(x1, y1, px1, py1, px2, py2) (x1>px1 && x1<px2 && y1>py1 && y2<py2 ? TRUE : FALSE)
 
 static void planegame_cloud_colision(CloudItem *clouditem)
 {
   double px1, px2, py1, py2;
   double x1, x2, y1, y2;
   GnomeCanvasItem *item;
-  static CloudItem *inCloudItem = NULL;
-
 
   if(clouditem==NULL)
     return;
@@ -362,18 +375,24 @@ static void planegame_cloud_colision(CloudItem *clouditem)
   gnome_canvas_item_get_bounds(planeitem,  &px1, &py1, &px2, &py2); 
   gnome_canvas_item_get_bounds(item,  &x1, &y1, &x2, &y2); 
 
-  if(((px1>x1 && px1<x2) ||
-      (px2>x1 && px2<x2)) &&
-      (((py1>y1 && py1<y2) ||
-	(py2>y1 && py2<y2))))
+  if(
+     ISIN(x1, y1, px1, py1, px2, py2) ||
+     ISIN(x2, y1, px1, py1, px2, py2) ||
+     ISIN(x1, y2, px1, py1, px2, py2) ||
+     ISIN(x2, y2, px1, py1, px2, py2)
+     )
     {
       if(plane_target == clouditem->number)
 	{
 	  gcompris_play_sound (SOUNDLISTFILE, "gobble");
 	  item2del_list = g_list_append (item2del_list, clouditem);
 	  plane_target++;
-	  gcompris_score_set(plane_target);
-	  
+
+	  if(gcomprisBoard->level==1)
+	    {
+	      gcompris_score_set(plane_target);
+	    }
+
 	  if(plane_target==plane_last_target)
 	    {
 	      /* Try the next level */
@@ -386,19 +405,6 @@ static void planegame_cloud_colision(CloudItem *clouditem)
 	      gcompris_play_sound (SOUNDLISTFILE, "bonus");
 	    }
 	}
-      else
-	{
-	  /* Oups, you get the wrong cloud */
-	  if(inCloudItem!=clouditem)
-	    gcompris_play_sound (SOUNDLISTFILE, "crash");
-	}
-      inCloudItem=clouditem;
-    }
-  else
-    {
-      /* OK, now we get out of the wrong cloud */
-      if(inCloudItem==clouditem)
-	inCloudItem=NULL;
     }
 }
 
@@ -496,7 +502,6 @@ static gint planegame_move_items (GtkWidget *widget, gpointer data)
 
   /* move the plane */
   planegame_move_plane(planeitem);
-
   dummy_id = gtk_timeout_add (speed,
 			      (GtkFunction) planegame_move_items, NULL);
 
@@ -513,7 +518,7 @@ static GnomeCanvasItem *planegame_create_item(GnomeCanvasGroup *parent)
   int i, min;
   CloudItem *clouditem;
 
-  gdk_font = gdk_font_load ("-adobe-times-medium-r-normal--*-240-*-*-*-*-*-*");
+  gdk_font = gdk_font_load (FONT_BOARD_BIG);
 
   /* Random cloud number */
   if(rand()%2==0)
@@ -592,7 +597,7 @@ static gint planegame_drop_items (GtkWidget *widget, gpointer data)
   planegame_add_new_item();
 
   drop_items_id = gtk_timeout_add (fallSpeed,
-				   (GtkFunction) planegame_drop_items, NULL);
+  				   (GtkFunction) planegame_drop_items, NULL);
   return (FALSE);
 }
 
