@@ -1,6 +1,6 @@
 /* gcompris - shapegame.c
  *
- * Time-stamp: <2002/05/02 01:30:42 bruno>
+ * Time-stamp: <2002/07/01 00:58:46 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -30,9 +30,17 @@
 #define SOUNDLISTFILE PACKAGE
 
 #define UNDEFINED "Undefined"
+#define SQUARE_LIMIT_DISTANCE 50
 
 static int gamewon;
 
+static gint addedname;	/* Defined the rules to apply to determine if the
+			   board is done.
+			   - by default it is puzzle like, each piece at its place
+			   - If addedname is set, then this value is compared to the
+			     sum of each xml name value of the placed pieces 
+			*/
+
 static GcomprisBoard *gcomprisBoard = NULL;
 
 typedef enum
@@ -59,6 +67,7 @@ struct _Shape {
   double zoomx;				/* x zoom factor */
   double zoomy;				/* y zoom factor */
   gint   position;			/* depth position 0=bottom other=intermediate */
+  char  *soundfile;			/* relative sound file to be played when pressing mouse button */
   ShapeType type;			/* Type of shape */
 
   GnomeCanvasItem *item;     	  	/* Canvas item for this shape */
@@ -66,9 +75,11 @@ struct _Shape {
   GnomeCanvasGroup *shape_list_group_root;
   guint shapelistgroup_index;	  	/* Root index which this item is in the shapelist */
   Shape *icon_shape;			/* Temporary Canvas icon shape for this shape */
+  Shape *target_shape;			/* If this is an icon shape then point to its shape */
   GnomeCanvasItem *bad_item;		/* Temporary bad placed Canvas item for this shape */
 
   gboolean found;			/* The user found this item */
+  gboolean placed;			/* The user placed this item */
   GnomeCanvasItem *target_point;       	/* Target point item for this shape */
 };
 
@@ -89,10 +100,24 @@ gchar *colorlist [] =
 /* This is the list of shape for the current game */
 static GList *shape_list	= NULL;
 static GList *shape_list_group	= NULL;
-static current_shapelistgroup_index	= -1;
+static int current_shapelistgroup_index	= -1;
+
+static GnomeCanvasItem *next_shapelist_item;		/* Canvas item button for the next shapelist */
+static GnomeCanvasItem *previous_shapelist_item;   	/* Canvas item button for the previous shapelist */
+
+/* Let's define the structure for the shapebox list that contains the icons of the shapes */
+typedef struct _ShapeBox ShapeBox;
+struct _ShapeBox {
+  double x;				/* x coordinate */
+  double y;				/* y coordinate */
+  double w;				/* width */
+  double h;				/* height */
+  guint  nb_shape_x;			/* Number of shape on x */
+  guint  nb_shape_y;			/* Number of shape on y */
+};
+static ShapeBox shapeBox;
 
 #define BUTTON_SPACE		40
-#define MAX_NUMBER_OF_SHAPES	8
 
 /* Hash table of all the shapes in the list of shapes (one by different pixmap plus icon list) */
 static GHashTable *shapelist_table = NULL;
@@ -117,7 +142,7 @@ static gboolean 	 write_xml_file(char *fname);
 static Shape 		*find_closest_shape(double x, double y, double limit);
 static Shape 		*create_shape(ShapeType type, char *name, char *pixmapfile,  GnomeCanvasPoints* points,
 				      char *targetfile, double x, double y, double l, double h, double zoomx, 
-				      double zoomy, guint position);
+				      double zoomy, guint position, char *soundfile);
 static gboolean 	 increment_sublevel(void);
 static void 		 create_title(char *name, double x, double y, char *justification);
 static gint		 item_event_ok(GnomeCanvasItem *item, GdkEvent *event, gpointer data);
@@ -233,6 +258,7 @@ static void start_board (GcomprisBoard *agcomprisBoard)
 	  gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas), "gcompris/gcompris-shapebg.jpg");
 	}
 
+      gamewon = FALSE;
       shapegame_next_level();
 
       pause_board(FALSE);
@@ -356,16 +382,51 @@ static void process_ok()
   GList *list;
   gboolean done = TRUE;
 
-  /* Loop through all the shapes to find if all target are found */
-  for(list = shape_list; list != NULL; list = list->next) {
-    Shape *shape = list->data;
+  /*
+   * Here I implements the resolving rules.
+   */
+  if(addedname == INT_MAX)
+    {
+      /* - Default is to be puzzle like. Check that each piece is at its place */
 
-    if(shape->type==SHAPE_TARGET)
-      {
-	if(shape->found==FALSE)
-	  done=FALSE;
+      /* Loop through all the shapes to find if all target are found */
+      for(list = shape_list; list != NULL; list = list->next) {
+	Shape *shape = list->data;
+	
+	if(shape->type==SHAPE_TARGET)
+	  {
+	    if(shape->found==FALSE)
+	      done=FALSE;
+	  }
       }
-  }
+    }
+  else
+    {
+      /* - if addedname is set, then adding int name field of placed piece must 
+       *   equals addedname
+       */
+      gint total = 0;
+
+      for(list = shape_list; list != NULL; list = list->next) {
+	Shape *shape = list->data;
+	gint   intname = 0;
+
+	printf("   shape = %s\n", shape->name);
+	if(shape->type==SHAPE_TARGET && shape->placed==TRUE)
+	  {
+	    intname = atoi(shape->name);
+	    total += intname;
+	    printf("      shape = %s   placed=TRUE\n", shape->name);
+	  }
+
+      }
+
+      if(total != addedname)
+	done = FALSE;
+
+      printf("checking for addedname=%d done=%d total=%d\n", addedname, done, total);
+    }
+
 
   if(done)
     {
@@ -425,7 +486,7 @@ static GnomeCanvasItem *shapegame_init_canvas(GnomeCanvasGroup *parent)
   shape_list_root_item = \
     gnome_canvas_item_new (parent,
 			   gnome_canvas_group_get_type (),
-			   "x", (double)gcomprisBoard->width/SHAPE_BOX_WIDTH_RATIO,
+			   "x", (double)0,
 			   "y", (double)0,
 			   NULL);
 
@@ -500,60 +561,71 @@ add_shape_to_list_of_shapes(Shape *shape)
 {
   GnomeCanvasItem *item;
   GdkPixbuf   *pixmap = NULL;
-  double SHAPE_ELEM_NUMBER_IN_HEIGHT = (double)(gcomprisBoard->height-BUTTON_SPACE)/MAX_NUMBER_OF_SHAPES;
   GnomeCanvasGroup *shape_list_group_root = NULL;
+  double ICON_GAP    = 5.0;
+  double ICON_HEIGHT = (double)(shapeBox.h / shapeBox.nb_shape_y) - ICON_GAP;
+  double ICON_WIDTH  = (double)(shapeBox.w / shapeBox.nb_shape_x) - ICON_GAP;
 
   if(!shapelist_table)
     shapelist_table= g_hash_table_new (g_str_hash, g_str_equal);
 
-  /* If the first list is full, add the previos/forward buttons */
-  if(g_hash_table_size(shapelist_table)==MAX_NUMBER_OF_SHAPES)
+  /*----------------------------------------------------------------------*/
+  /* If the first list is full, add the previous/forward buttons          */
+  if(g_hash_table_size(shapelist_table)==(shapeBox.nb_shape_x * shapeBox.nb_shape_y))
     {
       pixmap = gcompris_load_pixmap("gcompris/buttons/button_backward.png");
-      item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(shape_list_root_item),
-				    gnome_canvas_pixbuf_get_type (),
-				    "pixbuf", pixmap, 
-				    "x", (double) -30,
-				    "y", (double) BOARDHEIGHT-40,
-				    NULL);
+      previous_shapelist_item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(shape_list_root_item),
+						       gnome_canvas_pixbuf_get_type (),
+						       "pixbuf", pixmap, 
+						       "x", (double) shapeBox.x + (shapeBox.w/2) -
+						       gdk_pixbuf_get_width(pixmap) - 2,
+						       "y", (double) shapeBox.y + shapeBox.h,
+						       NULL);
       
-      gtk_signal_connect(GTK_OBJECT(item), "event",
+      gtk_signal_connect(GTK_OBJECT(previous_shapelist_item), "event",
 			 (GtkSignalFunc) item_event_ok,
 			 "previous_shapelist");
-      gtk_signal_connect(GTK_OBJECT(item), "event",
+      gtk_signal_connect(GTK_OBJECT(previous_shapelist_item), "event",
 			 (GtkSignalFunc) gcompris_item_event_focus,
 			 NULL);
       gdk_pixbuf_unref(pixmap);
       
-      
       pixmap = gcompris_load_pixmap("gcompris/buttons/button_forward.png");
-      item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(shape_list_root_item),
-				    gnome_canvas_pixbuf_get_type (),
-				    "pixbuf", pixmap, 
-				    "x", (double) 10,
-				    "y", (double) BOARDHEIGHT-40,
-				    NULL);
+      next_shapelist_item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(shape_list_root_item),
+						   gnome_canvas_pixbuf_get_type (),
+						   "pixbuf", pixmap, 
+						   "x", (double) shapeBox.x + (shapeBox.w/2) + 2,
+						   "y", (double) shapeBox.y + shapeBox.h,
+						   NULL);
       
-      gtk_signal_connect(GTK_OBJECT(item), "event",
+      gtk_signal_connect(GTK_OBJECT(next_shapelist_item), "event",
 			 (GtkSignalFunc) item_event_ok,
 			 "next_shapelist");
-      gtk_signal_connect(GTK_OBJECT(item), "event",
+      gtk_signal_connect(GTK_OBJECT(next_shapelist_item), "event",
 			 (GtkSignalFunc) gcompris_item_event_focus,
 			 NULL);
       gdk_pixbuf_unref(pixmap);
+      gnome_canvas_item_hide(next_shapelist_item);
+
   }
 
-  if(g_hash_table_size(shapelist_table)%MAX_NUMBER_OF_SHAPES==0)
+  /*----------------------------------------------------------------------*/
+  /* Do We need to create a new list                                      */
+  if(g_hash_table_size(shapelist_table)%(shapeBox.nb_shape_x * shapeBox.nb_shape_y)==0)
     {
       current_shapelistgroup_index++;
-      printf("Creation of the group of shape current_shapelistgroup_index=%d\n", current_shapelistgroup_index);
+      printf("Creation of the group of shape current_shapelistgroup_index=%d\n", 
+	     current_shapelistgroup_index);
+
       // Hide the previous group
       if(current_shapelistgroup_index>=1)
 	{
 	  printf(" Hide previous group\n");
 	  shape_list_group_root = GNOME_CANVAS_GROUP(g_list_nth_data(shape_list_group, 
 								     current_shapelistgroup_index-1));
-	  gnome_canvas_item_hide(shape_list_group_root);
+	  //gnome_canvas_item_hide(shape_list_group_root);
+	  item = g_list_nth_data(shape_list_group, current_shapelistgroup_index-1);
+	  gnome_canvas_item_hide(item);
 	}
 
       // We need to start a new shape list group
@@ -575,15 +647,25 @@ add_shape_to_list_of_shapes(Shape *shape)
       shape_list_group_root = g_list_nth_data(shape_list_group, current_shapelistgroup_index);
     }
 
-  /* This pixmap is not yet in the list of shapes */
+  /*----------------------------------------------------------------------*/
+  /* This pixmap is not yet in the list of shapes                         */
   if(g_hash_table_lookup (shapelist_table, shape->pixmapfile)==NULL)
     {
       double y_offset = 0;
+      double x_offset = 0;
       GdkPixbuf *pixmap = NULL;
 
-      y_offset = (SHAPE_ELEM_NUMBER_IN_HEIGHT/2 +
-		  (g_hash_table_size(shapelist_table)%MAX_NUMBER_OF_SHAPES)*
-		  SHAPE_ELEM_NUMBER_IN_HEIGHT);
+      y_offset = shapeBox.y + (ICON_HEIGHT/2 +
+			       (g_hash_table_size(shapelist_table) % shapeBox.nb_shape_y) *
+			       ICON_HEIGHT);
+      
+      x_offset = shapeBox.x + (ICON_WIDTH/2 +
+			       ((g_hash_table_size(shapelist_table) %
+				 ( shapeBox.nb_shape_x * shapeBox.nb_shape_y)) /
+				shapeBox.nb_shape_y) *
+			       ICON_WIDTH);
+      printf("  ICON_WIDTH = %f   ICON_HEIGHT = %f\n", ICON_WIDTH, ICON_HEIGHT);
+      printf("x_offset = %f   y_offset = %f\n", x_offset, y_offset);
 
       /* So this shape is not yet in, let's put it in now */
       g_hash_table_insert (shapelist_table, shape->pixmapfile, shape);
@@ -594,24 +676,24 @@ add_shape_to_list_of_shapes(Shape *shape)
 	  if(pixmap)
 	    {
 	      double w, h;
-	      guint SHAPE_SIZE = SHAPE_ELEM_NUMBER_IN_HEIGHT - 5;
+	      double ratio;
 	      Shape *icon_shape;
 	      
 	      /* Calc a zoom factor so that the shape will fit in the shapelist
 		 whatever its current size */
-	      w = SHAPE_SIZE;
-	      h = gdk_pixbuf_get_height(pixmap) * ( w / gdk_pixbuf_get_width(pixmap));
+	      w = ICON_WIDTH;
+	      h = gdk_pixbuf_get_height(pixmap) * (w / gdk_pixbuf_get_width(pixmap));
 	      
-	      if(h > SHAPE_SIZE)
+	      if(h > ICON_HEIGHT)
 		{
-		  h = SHAPE_SIZE;
+		  h = ICON_HEIGHT;
 		  w = gdk_pixbuf_get_width(pixmap) * ( h / gdk_pixbuf_get_height(pixmap));
 		}
 	      
 	      item = gnome_canvas_item_new (shape_list_group_root,
 					    gnome_canvas_pixbuf_get_type (),
 					    "pixbuf", pixmap, 
-					    "x", (double)-w/2,
+					    "x", (double)x_offset-w/2,
 					    "y", (double)y_offset-h/2,
 					    "width", (double) w,
 					    "height", (double) h,
@@ -624,12 +706,20 @@ add_shape_to_list_of_shapes(Shape *shape)
 					shape->pixmapfile, shape->points, shape->targetfile,
 					(double)0, (double)y_offset,
 					(double)w, (double)h, 
-					(double)1, (double)1,
-					0);
+					(double)shape->zoomx, (double)shape->zoomy,
+					0, shape->soundfile);
 	      icon_shape->item = item;
+	      icon_shape->target_shape = shape;
 	      icon_shape->shapelistgroup_index = current_shapelistgroup_index;
+	      shape->shapelistgroup_index = current_shapelistgroup_index;
+	      printf(" creation shape=%s shape->shapelistgroup_index=%d current_shapelistgroup_index=%d\n", 
+		     shape->name, 
+		     shape->shapelistgroup_index, current_shapelistgroup_index);
 	      icon_shape->shape_list_group_root = shape_list_group_root;
 	      setup_item(item, icon_shape);
+	      gtk_signal_connect(GTK_OBJECT(item), "event",
+				 (GtkSignalFunc) gcompris_item_event_focus,
+				 NULL);
 	    }
 	}
     }
@@ -637,7 +727,7 @@ add_shape_to_list_of_shapes(Shape *shape)
 
 /*
  * Find the closest shape from the given point if it is located at
- * a distance under the given limit.
+ * a distance under the given square limit.
  */
 static Shape *find_closest_shape(double x, double y, double limit)
 {
@@ -684,22 +774,30 @@ static void dump_shape(Shape *shape)
  */
 static void shape_goes_back_to_list(Shape *shape, GnomeCanvasItem *item)
 {
+  printf("shape_goes_back_to_list shape=%s shape->shapelistgroup_index=%d current_shapelistgroup_index=%d\n", shape->name, shape->shapelistgroup_index, current_shapelistgroup_index);
   if(shape->icon_shape!=NULL)
     {
+      if(shape->icon_shape->target_shape)
+	{
+	  shape->icon_shape->target_shape->placed = FALSE;
+	  printf("shape_goes_back_to_list setting shape->name=%s to placed=%d\n", 
+		 shape->icon_shape->target_shape->name,
+		 shape->icon_shape->target_shape->placed);
+	}
+
       /* There was a previous icon here, put it back to the list */
       gnome_canvas_item_move(shape->icon_shape->item, 
 			     shape->icon_shape->x - shape->x,
 			     shape->icon_shape->y - shape->y);
-      if(shape->shapelistgroup_index==current_shapelistgroup_index)
-	gnome_canvas_item_show(shape->icon_shape->item);
-      else
-	gnome_canvas_item_hide(shape->icon_shape->item);
+      gnome_canvas_item_show(shape->icon_shape->item);
 
       gcompris_set_image_focus(shape->icon_shape->item, TRUE);
       shape->icon_shape=NULL;
 
       gnome_canvas_item_hide(item);
       gcompris_play_sound (SOUNDLISTFILE, "gobble");
+
+
     }
 }
 
@@ -712,6 +810,7 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, Shape *shape)
    GdkCursor *fleur;
    static int dragging;
    double item_x, item_y;
+   gchar *soundfile=NULL;
 
    if(!get_board_playing())
      return FALSE;
@@ -765,6 +864,13 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, Shape *shape)
 		       shape->icon_shape=NULL;
 		     }
 		   break;
+		 case SHAPE_ICON:
+		   if (strcmp(shape->soundfile,UNDEFINED) != 0)
+		   {
+		   	soundfile=g_strdup(shape->soundfile);
+			gcompris_play_ogg(soundfile, NULL);
+		   }
+		   break;
 		 default:
 		   break;
 		 }
@@ -825,7 +931,7 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, Shape *shape)
 
 	   gnome_canvas_item_reparent (item, shape->shape_list_group_root);
 
-	   targetshape = find_closest_shape(item_x, item_y, 100);
+	   targetshape = find_closest_shape(item_x, item_y, SQUARE_LIMIT_DISTANCE);
 	   if(targetshape!=NULL)
 	     {
 	       /* Finish the placement of the grabbed item anyway */
@@ -844,7 +950,10 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, Shape *shape)
 		       gtk_object_destroy (GTK_OBJECT(targetshape->bad_item));
 		       targetshape->bad_item=NULL;
 		     }
-		   targetshape->found = TRUE;
+		   targetshape->found  = TRUE;
+		   shape->target_shape->placed = TRUE;
+		   printf("setting shape->name=%s to placed=%d\n", shape->target_shape->name,
+			  shape->target_shape->placed);
 		   gnome_canvas_item_show(targetshape->item);
 		 }
 	       else
@@ -854,6 +963,9 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, Shape *shape)
 		   GnomeCanvasItem *item;
 
 		   targetshape->found = FALSE;
+		   shape->target_shape->placed = TRUE;
+		   printf("setting shape->name=%s to placed=%d\n", shape->target_shape->name,
+			  shape->target_shape->placed);
 		   gnome_canvas_item_hide(targetshape->item);
 
 		   /* There is already a bad item, delete it */
@@ -861,16 +973,15 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, Shape *shape)
 		     gtk_object_destroy (GTK_OBJECT(targetshape->bad_item));
 
 		   pixmap = gcompris_load_pixmap(shape->pixmapfile);
-
 		   item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(shape_root_item),
 						 gnome_canvas_pixbuf_get_type (),
 						 "pixbuf", pixmap, 
 						 "x", (double)targetshape->x - (gdk_pixbuf_get_width(pixmap) 
-										* targetshape->zoomx)/2,
+										* shape->zoomx)/2,
 						 "y", (double)targetshape->y - (gdk_pixbuf_get_height(pixmap) 
-										* targetshape->zoomy/2),
-						 "width", (double) gdk_pixbuf_get_width(pixmap) * targetshape->zoomx,
-						 "height", (double) gdk_pixbuf_get_height(pixmap) * targetshape->zoomy,
+										* shape->zoomy/2),
+						 "width", (double) gdk_pixbuf_get_width(pixmap) * shape->zoomx,
+						 "height", (double) gdk_pixbuf_get_height(pixmap) * shape->zoomy,
 						 "width_set", TRUE, 
 						 "height_set", TRUE,
 						 NULL);
@@ -909,6 +1020,8 @@ item_event(GnomeCanvasItem *item, GdkEvent *event, Shape *shape)
 	       gnome_canvas_item_move(item, 
 				      shape->x - x + offset_x,
 				      shape->y - y + offset_y);
+	       shape->target_shape->placed = FALSE;
+
 	     }
 	 }
        break;
@@ -1035,10 +1148,19 @@ item_event_ok(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
       printf(" item event current_shapelistgroup_index=%d\n", current_shapelistgroup_index);
       if(!strcmp((char *)data, "previous_shapelist"))
 	{
+
 	  if(current_shapelistgroup_index>0)
 	    {
 	      current_shapelistgroup_index--;
 	    }
+
+	  if(current_shapelistgroup_index == 0)
+	    {
+	      gcompris_set_image_focus(item, TRUE);
+	      gnome_canvas_item_hide(previous_shapelist_item);
+	    } 
+
+	  gnome_canvas_item_show(next_shapelist_item);
 	}
       else if(!strcmp((char *)data, "next_shapelist"))
 	{	
@@ -1046,6 +1168,15 @@ item_event_ok(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 	    {
 	      current_shapelistgroup_index++;
 	    }
+
+	  if(current_shapelistgroup_index == g_list_length(shape_list_group)-1)
+	    {
+	      gcompris_set_image_focus(item, TRUE);
+	      gnome_canvas_item_hide(next_shapelist_item);
+	    }
+
+	  gnome_canvas_item_show(previous_shapelist_item);
+
 	}
 
       root_item = g_list_nth_data(shape_list_group, current_shapelistgroup_index);
@@ -1064,9 +1195,6 @@ setup_item(GnomeCanvasItem *item, Shape *shape)
   gtk_signal_connect(GTK_OBJECT(item), "event",
 		     (GtkSignalFunc) item_event,
 		     shape);
-  gtk_signal_connect(GTK_OBJECT(item), "event",
-		     (GtkSignalFunc) gcompris_item_event_focus,
-		     NULL);
 }
 
 /*
@@ -1214,7 +1342,7 @@ static Shape *
 create_shape(ShapeType type, char *name, char *pixmapfile, GnomeCanvasPoints* points,
 	     char *targetfile, double x, double y, 
 	     double w, double h, double zoomx, 
-	     double zoomy, guint position)
+	     double zoomy, guint position, char *soundfile)
 {
   Shape *shape;
   
@@ -1233,11 +1361,14 @@ create_shape(ShapeType type, char *name, char *pixmapfile, GnomeCanvasPoints* po
   shape->zoomy = zoomy;
   shape->position = position;
   shape->type = type;
+  shape->soundfile = g_strdup(soundfile);
 
   shape->bad_item = NULL;
   shape->icon_shape = NULL;
+  shape->target_shape = NULL;
 
-  shape->found = FALSE;
+  shape->found  = FALSE;
+  shape->placed = FALSE;
 
   /* add the shape to the list */
   shape_list = g_list_append(shape_list, shape);
@@ -1252,6 +1383,7 @@ add_xml_shape_to_data(xmlDocPtr doc, xmlNodePtr xmlnode, GNode * child)
   char *name, *cx, *cy, *cd, *czoomx, *czoomy, *cposition, *ctype, *justification;
   char *pixmapfile = NULL;
   char *targetfile = NULL;
+  char *soundfile = NULL;
   double x, y, zoomx, zoomy;
   GnomeCanvasPoints* points = NULL;
   gchar **d;
@@ -1260,6 +1392,7 @@ add_xml_shape_to_data(xmlDocPtr doc, xmlNodePtr xmlnode, GNode * child)
   ShapeType type = SHAPE_TARGET;
   Shape *shape;
   xmlNodePtr xmlnamenode;
+  char *locale;
 
   if(/* if the node has no name */
      !xmlnode->name ||
@@ -1280,6 +1413,9 @@ add_xml_shape_to_data(xmlDocPtr doc, xmlNodePtr xmlnode, GNode * child)
   /* if unspecified, make it UNDEFINED */
   if(!targetfile) targetfile = UNDEFINED;
 
+  soundfile = xmlGetProp(xmlnode,"sound");
+  /* if unspecified, make it UNDEFINED */
+  if(!soundfile) soundfile = UNDEFINED;
   /*********************************/
   /* get the points for a polygone */
   /* The list of points is similar to the one define in the SVG standard */
@@ -1319,6 +1455,10 @@ add_xml_shape_to_data(xmlDocPtr doc, xmlNodePtr xmlnode, GNode * child)
   if(!cy) cy = "100";
   y = atof(cy);
 
+  /* Back up the current locale to be sure to load well C formated numbers */
+  locale = gcompris_get_locale();
+  gcompris_set_locale("C");
+
   /* get the ZOOMX coord of the shape */
   czoomx = xmlGetProp(xmlnode,"zoomx");
   if(!czoomx) czoomx = "1";
@@ -1334,6 +1474,9 @@ add_xml_shape_to_data(xmlDocPtr doc, xmlNodePtr xmlnode, GNode * child)
   if(!cposition) cposition = "0";
   position = atoi(cposition);
 
+  /* Back to the user locale */
+  gcompris_set_locale(locale);
+
   /* get the TYPE of the shape */
   ctype = xmlGetProp(xmlnode,"type");
   if(!ctype) ctype = "SHAPE_TARGET"; /* SHAPE_TARGET is default */
@@ -1378,7 +1521,7 @@ add_xml_shape_to_data(xmlDocPtr doc, xmlNodePtr xmlnode, GNode * child)
       /* WARNING : I do not initialize the width and height since I don't need them */
       shape = create_shape(type, name, pixmapfile, points, targetfile, x, y, 
 			   (double)0, (double)0,
-			   zoomx, zoomy, position);
+			   zoomx, zoomy, position, soundfile);
       add_shape_to_canvas(shape);
     } 
   else if (g_strcasecmp(xmlnode->name,"Title")==0)
@@ -1413,7 +1556,8 @@ static gboolean
 read_xml_file(char *fname)
 {
   /* pointer to the new doc */
-  xmlDocPtr doc;
+  xmlDocPtr  doc;
+  gchar     *tmpstr;
   
   g_return_val_if_fail(fname!=NULL,FALSE);
   
@@ -1423,7 +1567,7 @@ read_xml_file(char *fname)
       g_warning(_("Couldn't find file %s !"), fname);
       return FALSE;
     }
-      g_warning(_("find file %s !"), fname);
+  g_warning(_("find file %s !"), fname);
 
   /* parse the new file and put the result into newdoc */
   doc = xmlParseFile(fname);
@@ -1440,7 +1584,68 @@ read_xml_file(char *fname)
     xmlFreeDoc(doc);
     return FALSE;
   }
-  
+
+  /*--------------------------------------------------*/
+  /* Read OkIfAddedName property */
+  tmpstr = xmlGetProp(doc->children,"OkIfAddedName");
+  /* if unspecified, make it INT_MAX */
+  if(!tmpstr) 
+      addedname = INT_MAX;
+  else
+      addedname = atoi(tmpstr);
+  printf("addedname=%d\n", addedname);
+
+  /*--------------------------------------------------*/
+  /* Read ShapeBox property */
+  tmpstr = xmlGetProp(doc->children,"shapebox_x");
+  /* if unspecified, use the default value */
+  if(!tmpstr) 
+      shapeBox.x = 15;
+  else
+      shapeBox.x = atof(tmpstr);
+  printf("shapeBox.x=%f\n", shapeBox.x);
+
+  tmpstr = xmlGetProp(doc->children,"shapebox_y");
+  /* if unspecified, use the default value */
+  if(!tmpstr) 
+      shapeBox.y = 25;
+  else
+      shapeBox.y = atof(tmpstr);
+  printf("shapeBox.y=%f\n", shapeBox.y);
+
+  tmpstr = xmlGetProp(doc->children,"shapebox_w");
+  /* if unspecified, use the default value */
+  if(!tmpstr) 
+      shapeBox.w = 80;
+  else
+      shapeBox.w = atof(tmpstr);
+  printf("shapeBox.w=%f\n", shapeBox.w);
+
+  tmpstr = xmlGetProp(doc->children,"shapebox_h");
+  /* if unspecified, use the default value */
+  if(!tmpstr) 
+      shapeBox.h = 430;
+  else
+      shapeBox.h = atof(tmpstr);
+  printf("shapeBox.h=%f\n", shapeBox.h);
+
+  tmpstr = xmlGetProp(doc->children,"shapebox_nb_shape_x");
+  /* if unspecified, use the default value */
+  if(!tmpstr) 
+      shapeBox.nb_shape_x = 1;
+  else
+      shapeBox.nb_shape_x = atoi(tmpstr);
+  printf("shapeBox.nb_shape_x=%d\n", shapeBox.nb_shape_x);
+
+  tmpstr = xmlGetProp(doc->children,"shapebox_nb_shape_y");
+  /* if unspecified, use the default value */
+  if(!tmpstr) 
+      shapeBox.nb_shape_y = 5;
+  else
+      shapeBox.nb_shape_y = atoi(tmpstr);
+  printf("shapeBox.nb_shape_y=%d\n", shapeBox.nb_shape_y);
+
+
   /* parse our document and replace old data */
   parse_doc(doc);
   
@@ -1465,6 +1670,7 @@ write_shape_to_xml(xmlNodePtr xmlnode, Shape *shape)
   /* set properties on it */
   xmlSetProp(newxml,"name",shape->name);
   xmlSetProp(newxml,"pixmapfile",shape->pixmapfile);
+  xmlSetProp(newxml,"sound",shape->soundfile);
 
   tmp = g_strdup_printf("%f", shape->x);
   xmlSetProp(newxml,"x",tmp);
