@@ -1,6 +1,6 @@
 /* gcompris - gcompris.c
  *
- * Time-stamp: <2002/05/01 22:50:01 bruno>
+ * Time-stamp: <2002/06/30 23:28:15 bruno>
  *
  * Copyright (C) 2000,2001 Bruno Coudoin
  *
@@ -20,8 +20,10 @@
  */
 
 #include <signal.h>
+#include <locale.h>
 
 #include "gcompris.h"
+#include <locale.h>
 #include <popt-gnome.h>
 
 #include "cursor.h"
@@ -376,7 +378,7 @@ static void setup_window ()
   init_plugins();
 
   /* Load and Run the menu */
-  gcomprisBoardMenu = gcompris_read_xml_file(PACKAGE_DATA_DIR "/menu.xml");
+  gcomprisBoardMenu = gcompris_read_xml_file(PACKAGE_DATA_DIR INITIAL_MENU);
   if(!board_check_file(gcomprisBoardMenu))
     g_error("Cant't find the menu board or plugin execution error");
 
@@ -391,30 +393,22 @@ static void setup_window ()
 void gcompris_end_board()
 {
   if (get_current_gcompris_board()->previous_board == NULL)
-    {
-      /* We are in the upper menu: leave GCompris? */
-      quit_cb(NULL, NULL);
+    /* We are in the upper menu */
+    board_play (gcomprisBoardMenu);
+  else
+    /* Run the previous board */
+    board_play (get_current_gcompris_board()->previous_board);
+}
 
-      /* Oups, the user changed his mind : restart the menu */
-      board_play (get_current_gcompris_board());
-      return;
-    }
-
-  /* Run the previous board */
-  board_play (get_current_gcompris_board()->previous_board);
+void gcompris_exit()
+{
+  gcompris_properties_save(properties);
+  gtk_main_quit ();
 }
 
 static void quit_cb (GtkWidget *widget, gpointer data)
 {
-  // FIXME: Should be implemented as a canvas dialog window
-  //  if (end_board_box ())
-  //    return;
-
-  /*      cleanup_plugins(); */
-  gcompris_properties_save(properties);
-
-  gtk_main_quit ();
-
+  gcompris_exit();
 }
 
 static void load_properties ()
@@ -453,7 +447,18 @@ void gcompris_set_locale(gchar *locale)
 
   gcompris_locale = g_strdup(setlocale(LC_ALL, locale));
   printf("gcompris_set_locale requested %s got %s\n", locale, gcompris_locale);
-  /* WARNING: This does not update gettext translation */
+
+  /* Override the env locale to what the user requested */
+  setenv ("LC_ALL", gcompris_get_locale(), TRUE);
+  setenv ("LC_MESSAGES", gcompris_get_locale(), TRUE);
+  setenv ("LANGUAGE", gcompris_get_locale(), TRUE);
+  setenv ("LANG", gcompris_get_locale(), TRUE);
+ 
+ /* WARNING: This does not update gettext translation */
+  /* Call for localization startup */
+  bindtextdomain (PACKAGE, PACKAGE_LOCALE_DIR);
+  textdomain (PACKAGE);
+
 }
 
 /*****************************************
@@ -462,7 +467,7 @@ void gcompris_set_locale(gchar *locale)
  */
 
 int
-main (int argc, char *argv[])
+gcompris_init (int argc, char *argv[])
 {
   int c;
   poptContext optCon;
@@ -470,9 +475,6 @@ main (int argc, char *argv[])
   /* To have some real random behaviour */
   srand (time (NULL));
 
-  bindtextdomain (PACKAGE, PACKAGE_LOCALE_DIR);
-  textdomain (PACKAGE);
-
   load_properties ();
 
   // Set the default gcompris cursor
@@ -480,7 +482,7 @@ main (int argc, char *argv[])
 
   // Set the user's choice locale
   gcompris_set_locale(properties->locale);
-  
+
   initSound();
   
   gnome_init_with_popt_table (PACKAGE, VERSION, argc, argv, command_line, 0, &optCon);
