@@ -40,10 +40,10 @@ typedef struct {
 } tsSound;
 
 void	 gcompris_play_sound (const char *soundlistfile, const char *which);
-void gcompris_play_ogg(char *, ...);
-void setSoundPolicy(int);
-int getSoundPolicy();
-void initSound();
-pid_t exec_play(char *);
+void	 gcompris_play_ogg(char *, ...);
+void	 setSoundPolicy(int);
+int	 getSoundPolicy(void);
+void	 initSound(void);
+pid_t	 exec_play(char *);
 
 #endif
